***********************************************************************************************
* Module:	Startup
*
* Purpose:	To invoke the SLIDRET system.
*
* Algorithm:
*	This procedure performs 2 checks before starting the program:
* 	1. Prevents the user from opening a second instance of this program. (Error 1569)
* 	2. Ensure that the data directories contains ALL of the sliddbf data files. This also traps
* 	   a common error where the user attempts to access an empty CD drive.
*
*	NOTE: THE GETDIR MESSAGE BOX REQUIRES FRENCH TRANSLATIONS!!!!!!!!!!!!!!
*	Certain public variables have been declared at this point so that they can be accessed from Frsretrieval,
*   retproc.prg and startup.prg
*
* Files:	tblsyscf
*			tblmess1
*
* Calls:	procedure faterror in retprog.prg
*			procedure checkdatadir in retprog.prg
*
* Modifications:
*	March 1999
*	Added logical variable that duplicates the function of frsRetrieval.TestEnvironment.
*	This is needed to determine whether to use production year table tblYearP, or test
*	year table tblYearT.  Not needed in the past because there was only one year table, tblYear.
*	!!!! Change this variable to .f. when preparing a client program. !!!!!
*
*	October 1999
*	2 year tables no longer needed.  One tblyear can now be used for both production
*	and testing (see above note for March 1999).  All references to tblYearp, tblYeart,
*	and lTestEnvironment commented out.
*
*******************************************************************************************


PUBLIC Gndispcode
PUBLIC Glfromstartup
PUBLIC Gnerror
PUBLIC Gclanguage 			&& Indicates the user's language preference ( 'E' = english, 'F' = french)

*!*	LOCAL lTestEnvironment		&& Running in Test environment (T) or production environment (F)

* Initialize variables
*!*	lTestEnvironment = .T.
lvaliddir = .T.
Glfromstartup = .T.
Gnerror = 0

SET PROCEDURE TO retproc
ON ERROR DO faterror WITH MESSAGE(), MESSAGE(1), PROGRAM(), ERROR()


* Open tables
Ncurrentworkarea = SELECT()
SELECT 0
USE tblsyscf

*!*		wait 'after reopening tblsyscf and before setting gnerror' window
*!*		wait 'gnerror = ' + str(gnerror) window
* If another version of this program is running, then an error must have occurred when attempting to open
* the systemdbf database. This error generates the foxpro error no. 1569


IF Gnerror = 1705 OR Gnerror = 1569 OR Gnerror = 3	OR Gnerror = 1881 OR Gnerror = 2005					&&OR gnerror = 13
*!*		wait 'closing program' window
	Gnerror = 0								&& clear error number
	WAIT 'inside if' WINDOW
	ON ERROR 								&& clear error handling routine
	CLEAR PROGRAM							&& Close program

ELSE										&& This is the only version running, go ahead with data dir error check..

	SELECT 0
	USE tblmess1

*!*		SELECT 0
*!*		IF lTestEnvironment = .T.
*!*			USE tblyeart ALIAS tblyear
*!*		ELSE
*!*			USE tblyearp ALIAS tblyear
*!*		ENDIF

	SELECT 0
	USE tblyear

* Ensure that all tables are in data directory
	SELECT tblsyscf
	cdataloc = RTRIM(tblsyscf.cdatadir)

	DO checkdatadir WITH lvaliddir, cdataloc

	IF lvaliddir = .F.					&& Repeat loop until user cancels (quits program), or a valid dat dir is selected
		DO WHILE lvaliddir = .F.
			Gnerror = 3001				&& Generate Foxpro error which will cause error routine (faterror)to be called

			DO faterror WITH MESSAGE(), MESSAGE(1), PROGRAM(), ERROR()
			Gnerror = 0									&& Clear error

			DO CASE
			CASE Gndispcode = 1					&& OK, open dialog box and let user search for directory
				cdataloc = GETDIR(tblsyscf.cdatadir,'Where is your data?')
				IF NOT EMPTY(cdataloc)
					SELECT tblsyscf
					REPLACE tblsyscf.cdatadir WITH RTRIM(cdataloc)
					DO checkdatadir WITH lvaliddir, cdataloc
				ENDIF

			CASE Gndispcode = 2					&& User selected Cancel, quit program
				SELECT tblsyscf
				USE								&& Close table
				QUIT							&& Terminate program
			ENDCASE

		ENDDO			&&{DO WHILE lvaliddir = .F.}
	ENDIF			&&{IF lvaliddir = .F.}


* Close tables, they will be reopened from main program. If these tables are not closed here, 
* then they would need to be closed when exiting program. Either option is feasible.
	SELECT tblsyscf
	USE
	SELECT tblmess1
	USE
	SELECT tblyear
	USE

	Glfromstartup = .F.
*!*		wait 'loading DATARET7' window

	DO FORM DATARET7						&& Start program

* Remove comment from line below in compiled version.
* For SLID clients, the following line must not be commented out.
* But for SDD, the Read Events must be commented out.
	READ EVENTS					&& Needed in the compiled version to trigger reading of events
	
ENDIF

**************************************************************************************************************************


